@@ -472,11 +472,8 @@ pub mod private {
 
 	#[cfg(feature = "database")]
 	pub use gotham_middleware_diesel::Repo;
-
 	#[cfg(feature = "openapi")]
-	pub use indexmap::IndexMap;
-	#[cfg(feature = "openapi")]
-	pub use openapi_type::{openapi, OpenapiSchema, OpenapiType};
+	pub use openapi_type::{indexmap::IndexMap, openapi, OpenapiSchema, OpenapiType};
 }
 
 #[cfg(feature = "auth")]
